@@ -94,7 +94,7 @@ public:
 	}
 
 protected:
-	socket_event_source() = default;
+	socket_event_source() = delete;
 	explicit socket_event_source(socket_event_source* root)
 		: root_(root)
 	{}
@@ -364,6 +364,44 @@ public:
 	virtual int read(void* buffer, unsigned int size, int& error) = 0;
 	virtual int write(void const* buffer, unsigned int size, int& error) = 0;
 
+	template<typename T, std::enable_if_t<std::is_signed_v<T>, int> = 0>
+	int read(void* buffer, T size, int& error)
+	{
+		if (size < 0) {
+			error = EINVAL;
+			return -1;
+		}
+
+		return read(buffer, static_cast<unsigned int>(size), error);
+	}
+	template<typename T, std::enable_if_t<std::is_unsigned_v<T> && (sizeof(T) > sizeof(unsigned int)), int> = 0>
+	int read(void* buffer, T size, int& error)
+	{
+		if (size > std::numeric_limits<unsigned int>::max()) {
+			size = std::numeric_limits<unsigned int>::max();
+		}
+		return read(buffer, static_cast<unsigned int>(size), error);
+	}
+
+	template<typename T, std::enable_if_t<std::is_signed_v<T>, int> = 0>
+	int write(void const* buffer, T size, int& error)
+	{
+		if (size < 0) {
+			error = EINVAL;
+			return -1;
+		}
+
+		return write(buffer, static_cast<std::make_unsigned_t<T>>(size), error);
+	}
+	template<typename T, std::enable_if_t<std::is_unsigned_v<T> && (sizeof(T) > sizeof(unsigned int)), int> = 0>
+	int write(void const* buffer, T size, int& error)
+	{
+		if (size > std::numeric_limits<unsigned int>::max()) {
+			size = std::numeric_limits<unsigned int>::max();
+		}
+		return write(buffer, static_cast<unsigned int>(size), error);
+	}
+	
 	virtual void set_event_handler(event_handler* pEvtHandler, fz::socket_event_flag retrigger_block = fz::socket_event_flag{}) = 0;
 
 	virtual native_string peer_host() const = 0;
@@ -389,7 +427,7 @@ public:
 	virtual int shutdown_read() = 0;
 
 protected:
-	socket_interface() = default;
+	socket_interface() = delete;
 
 	explicit socket_interface(socket_event_source * root)
 		: socket_event_source(root)
@@ -616,6 +654,18 @@ public:
 	 */
 	virtual int shutdown_read() override;
 
+	virtual int connect(native_string const& host, unsigned int port, address_type family = address_type::unknown) override {
+		return next_layer_.connect(host, port, family);
+	}
+
+	virtual int shutdown() override {
+		return next_layer_.shutdown();
+	}
+
+	virtual socket_state get_state() const override {
+		return next_layer_.get_state();
+	}
+
 protected:
 	/**
 	 * Call in a derived classes handler for fz::socket_event. Results in
